==> shardingsphere-infra-executor-5.1.2-sources.jar: org/apache/shardingsphere/infra/executor/sql/execute/engine/raw/callback/RawExecutorCallback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.executor.sql.execute.engine.raw.callback;

import org.apache.shardingsphere.spi.annotation.SingletonSPI;

import java.sql.SQLException;
import java.util.Collection;
import java.util.Map;

/**
 * Raw executor callback.
 *
 * @param <I> type of input value
 * @param <O> type of output value
 */
@SingletonSPI
public interface RawExecutorCallback<I, O> {
    
    /**
     * Execute.
     *
     * @param inputs input values
     * @param isTrunkThread is execution in trunk thread
     * @param dataMap data map
     * @return execution results
     * @throws SQLException throw when execute failure
     */
    Collection<O> execute(Collection<I> inputs, boolean isTrunkThread, Map<String, Object> dataMap) throws SQLException;
}

==> shardingsphere-infra-executor-5.2.0-sources.jar: org/apache/shardingsphere/infra/executor/sql/execute/engine/raw/callback/RawExecutorCallback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.executor.sql.execute.engine.raw.callback;

import org.apache.shardingsphere.infra.util.spi.annotation.SingletonSPI;

import java.sql.SQLException;
import java.util.Collection;
import java.util.Map;

/**
 * Raw executor callback.
 *
 * @param <I> type of input value
 * @param <O> type of output value
 */
@SingletonSPI
public interface RawExecutorCallback<I, O> {
    
    /**
     * Execute.
     *
     * @param inputs input values
     * @param isTrunkThread is execution in trunk thread
     * @param dataMap data map
     * @return execution results
     * @throws SQLException throw when execute failure
     */
    Collection<O> execute(Collection<I> inputs, boolean isTrunkThread, Map<String, Object> dataMap) throws SQLException;
}
